# Django Name [![Build Status](https://github.com/unt-libraries/django-name/actions/workflows/test.yml/badge.svg?branch=master)](https://github.com/unt-libraries/django-name/actions) [![Docs Status](https://img.shields.io/badge/docs-latest-blue.svg)](https://django-name.readthedocs.io) [![PyPI Version](https://img.shields.io/pypi/v/django-name.svg)](https://pypi.python.org/pypi/django-name)
Python Implementation of NACO Normalization Rules

The Name App is a tool originally developed for documenting names used by the UNT Libraries in its various digital library systems and collections. The app provides a consistent way of communicating the authorized version of a name and information about the name that is useful for reuse. The Name App generates a unique URL for each name that can be used to unambiguously refer to a person, organization, event, building or piece of software. In addition to an HTML page for each name there are a number of other formats available for each record including a MADS XML version and a simple JSON representation. A key feature of the UNT Name App is the ability to link to other vocabularies such as the Virtual International Authority File (VIAF), the Library of Congress Name Authority File, or Wikipedia.  
 
 ---

## Installation

For installation instructions, see the [Installation](https://django-name.readthedocs.io/en/latest/installation.html) page in the docs.
 
## License

See LICENSE.

## Acknowledgements

django-name was developed at the UNT Libraries.

Contributors:

- [Joey Liechty](https://github.com/yeahdef)
- [Damon Kelley](https://github.com/damonkelley)
- [Lauren Ko](https://github.com/ldko)
- [Mark Phillips](https://github.com/vphill)
- [Gio Gottardi](https://github.com/somexpert)
- [Madhulika Bayyavarapu](https://github.com/madhulika95b)
- [Gracie Flores-Hays](https://github.com/gracieflores)
- [Trey Clark](https://github.com/clarktr1)


## Requirements
- Python 3.9 or later 


## Development

There are three ways to set up this environment locally.

## Docker

Install [Docker](https://docs.docker.com). Instructions differ based on installation method. 

Clone the repository.
```sh
$ git clone https://github.com/unt-libraries/django-name.git
$ cd django-name
```

Warm up the Mariadb database. This only needs to be done when the database container doesn't exist yet. This will take about a minute once the image has been pulled.
```sh
$ docker compose up -d mariadb
```

Start the app and run the migrations.
```sh
# start the app
$ docker compose up -d

# run the migrations
$ docker compose run --rm web ./manage.py migrate

# optional: add a superuser in order to login to the admin interface
$ docker compose run --rm web ./manage.py createsuperuser
```
At this point you should be able to access your local instance of the site by visiting `<dockerhost>:8000/name/`

The code is in a volume that is shared between your workstation and the web container, which means any edits you make on your workstation will also be reflected in the Docker container. No need to rebuild the container to pick up changes in the code.

However, if the requirements files change, it is important that you rebuild the web container for those packages to be installed. This is something that could happen when switching between feature branches, or when pulling updates from the remote.

```sh
# stop the app
$ docker compose stop

# remove the web container
$ docker compose rm web

# rebuild the web container
$ docker compose build web

# start the app
$ docker compose up -d
```

## Developing with Podman and Podman-Compose
[Install or Enable Podman](https://podman.io/getting-started/installation).

[Install Podman Compose](https://github.com/containers/podman-compose).
```sh
$ sudo dnf install podman-compose
```

You will follow the same steps as above, starting with `Clone the repository`. For all of the docker steps, you will have to replace the word `docker` with `podman`.

If you have SELinux, you may need to temporarily add `:Z` to the web volumes in the docker-compose.yml. It will look like `.:/app/:Z`. You may also need to use `sudo` for your podman-compose commands.

## Traditional Setup

Clone the repository.
```sh
$ git clone https://github.com/unt-libraries/django-name.git
$ cd django-name
```

Install the mysql development package. The command depends on your system:
```sh
# Red Hat
sudo dnf install mysql-devel

# Ubuntu / Windows (WSL)
sudo apt install libmysqlclient-dev

# macOS via Homebrew
brew install mysql-client
```

Create a virtual environment and activate it
```sh
$ python -m venv env
$ source env/bin/activate
```

Install the dev dependencies
```sh
$ pip install .'[dev,test,codestyle]'
```

Replace the `DATABASES` Django setting in `./tests/settings/dev.py` with
```python
DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': './db.sqlite3', 
    }
}
```
Add table data
```sh
$ python manage.py migrate
```

Start dev instance
```sh
$ python manage.py runserver
```

The app should be available at `http://localhost:8000/name/`

## Running the Tests
NOTE: tests will not pass without the mariadb and postgres databases available. 

To run the tests via Tox, use this command. If you are using podman-compose, swap the word `docker` with `podman` for the commands below.
```sh
$ docker compose run --rm web tox
```
